@@ -4,7 +4,7 @@ from kivy.uix.button import Button
 from kivy.uix.screenmanager import ScreenManager
 from kivymd.uix.boxlayout import MDBoxLayout
 from noteapp.apps.video import VideoScreen
-from noteapp.games import GameManageScreen
+#from noteapp.games import GameManageScreen
 from noteapp.utils.widget import widget_wrap
 
 
@@ -15,7 +15,7 @@ class AppLayout(MDBoxLayout):
         self.screen_manager = ScreenManager()
 
         self.screen_manager.add_widget(VideoScreen(name='screen1'))
-        #self.screen_manager.add_widget(GameManageScreen(name='games'))
+        # self.screen_manager.add_widget(GameManageScreen(name='games'))
         self.screen_manager.add_widget(VideoScreen(name='games'))
         self.screen_manager.add_widget(VideoScreen(name='screen3'))
 
